#include <python.h>
#include "lsapi.h"
#include "pyerror.h"
#include "LSAPIBangs.h"

LSAPIBangs *LSAPIBangs::bangmgr = 0;

LSAPIBangs::LSAPIBangs (void) {
}

PyObject *LSAPIBangs::AddBangCommand (PyObject *self, PyObject *args){
    PyError::PyShowError ("PyScript Error", "AddBangCommand is deprecated. Use AddBangCommandEx instead","");
    return Py_BuildValue("i", 0);
}

PyObject *LSAPIBangs::AddBangCommandEx (PyObject *self, PyObject *args){
    char *bangname;
    PyObject *bangfunc;

    if (!PyArg_ParseTuple (args, "sO", &bangname, &bangfunc))
        return Py_BuildValue("i", 0);
    if (PyCallable_Check (bangfunc) == 0)
        return Py_BuildValue("i", 0);
    bangmgr->removeBang (string (bangname));   
    bangmgr->addBang (string (bangname), bangfunc);
    return Py_BuildValue("i", 0);
}

PyObject *LSAPIBangs::ParseBangCommand (PyObject *self, PyObject *args){
    HWND hCaller;
    CHAR *command,*bangargs;

    if (!PyArg_ParseTuple (args, "iss", &hCaller, &command, &bangargs)) {
        PyError::PyShowError (string ("PyScript Error"), string ("An error occurred while executing ParseBangCommand ") + string (command), "");
        return Py_BuildValue("i", 0);
    }
    /*FIXME: python doesn't have "NULL" and ParseBangCommand doesn't like zero ("0") instead */
    if (hCaller == 0)
        hCaller = NULL;

    BOOL result = ::ParseBangCommand (NULL, command, bangargs);
    if (result == TRUE) {
        return Py_BuildValue("i", 1);
    }
    else {
        return Py_BuildValue("i", 0);
    }
}

PyObject *LSAPIBangs::RemoveBangCommand (PyObject *self, PyObject *args){
    char *bangname;

    if (!PyArg_ParseTuple (args, "s", &bangname))
        return Py_BuildValue("i", 0);
    bangmgr->removeBang (string (bangname));
    return Py_BuildValue("i", 0);
}

void LSAPIBangs::addBang (string bangname, PyObject *pybangfunc) {
    bangmap[bangname.c_str()] = pybangfunc; 

    if (::AddBangCommandEx (bangname.c_str(), dispatchBang) != TRUE)
        PyError::PyShowError ("PyScript Error", string ("Error while registering the bang ") + bangname,"");
}

void LSAPIBangs::removeBang (string bangname) {
    bangmap.erase (bangname.c_str());
    ::RemoveBangCommand (bangname.c_str());
}

void LSAPIBangs::dispatchBang (HWND hCaller, const CHAR *command, const CHAR *args) {
    PyObject *pyfunc, *pyargs, *pyresult;

    BangMap::iterator iter = bangmgr->bangmap.find (command);
    if (iter == bangmgr->bangmap.end())
        return;
    pyfunc = iter->second;

    if (PyCallable_Check (pyfunc) != 0) {
        if ((args != NULL)|| strcmp (args, ""))
            pyargs = Py_BuildValue ("(iss)", hCaller, command, args);
        else
            pyargs = NULL;

		pyresult = PyObject_CallObject (pyfunc, pyargs);
        if (PyErr_Occurred ())
        {
            PyError::PyShowError (string ("PyScript Error"), string ("While executing the bang ")+ string(command)+
                             string(" an error occurred"),string(""));
        }
        if (pyresult != NULL)
            Py_DECREF (pyresult);
        if (pyargs != NULL)
            Py_DECREF (pyargs);
    }
}