#include <python.h>
#include "PyError.h"
#include "lsapi.h"
#include "LSAPIConfig.h"

PyObject *LSAPIConfig::GetRCBool (PyObject *self, PyObject *args) {
    char *key;
    int ifFound;
    BOOL result;

	if (!PyArg_ParseTuple (args, "sb", &key, &ifFound)) {
        PyError::PyShowError ("PyScript Error", "Error while decoding an argument for GetRCBool", "");
		return Py_BuildValue("i", 0);
	}
    result = ::GetRCBool (key, ifFound);
    if (result == TRUE)
        return Py_BuildValue("i", 1);
    else
        return Py_BuildValue("i", 0);
}
 
PyObject *LSAPIConfig::GetRCBoolDef (PyObject *self, PyObject *args) {
    char *key;
    int bdefault;
    BOOL result;

	if (!PyArg_ParseTuple (args, "sb", &key, &bdefault)) {
        PyError::PyShowError ("PyScript Error", "Error while decoding an argument for GetRCBoolDef", "");
		return Py_BuildValue("i", 0);
	}
    result = ::GetRCBool (key, bdefault);
    if (result == TRUE)
        return Py_BuildValue("i", 1);
    else
        return Py_BuildValue("i", 0);
}

PyObject *LSAPIConfig::GetRCColor (PyObject *self, PyObject *args) {
    char *key;
    COLORREF cdefault;
    COLORREF result;

	if (!PyArg_ParseTuple (args, "sb", &key, &cdefault)) {
        PyError::PyShowError ("PyScript Error", "Error while decoding an argument for GetRCBool", "");
		return Py_BuildValue("i", 0);
	}
    result = ::GetRCColor (key, cdefault);

    return Py_BuildValue("i", result);
}

PyObject *LSAPIConfig::GetRCCoordinate (PyObject *self, PyObject *args) {
    //FIXME
    return Py_BuildValue("i", 0);
}

PyObject *LSAPIConfig::GetRCInt (PyObject *self, PyObject *args) {
    char *key;
    int idefault;
    int result;

	if (!PyArg_ParseTuple (args, "sb", &key, &idefault)) {
        PyError::PyShowError ("PyScript Error", "Error while decoding an argument for GetRCInt", "");
		return Py_BuildValue("i", 0);
	}
    result = ::GetRCInt (key, idefault);
    return Py_BuildValue("i", result);
}

PyObject *LSAPIConfig::GetRCLine (PyObject *self, PyObject *args) {
    char *key;
    char *buffer;
    char localbuffer[MAX_LINE_LENGTH*2] = {""};
    unsigned int bufferlen;
    char *ldefault;
    BOOL result;

	if (!PyArg_ParseTuple (args, "ssis", &key, &buffer, &bufferlen, &ldefault)) {
        PyError::PyShowError ("PyScript Error", "Error while decoding an argument for GetRCLine", "");
		return Py_BuildValue("i", 0);
	}
    result = ::GetRCLine (key, localbuffer, MAX_LINE_LENGTH*2, ldefault);
    if (result == false)
        return Py_BuildValue("s", "");;

    return Py_BuildValue("s", localbuffer);
}

PyObject *LSAPIConfig::GetRCString (PyObject *self, PyObject *args) {
    char *key;
    char *buffer;
    char localbuffer[MAX_LINE_LENGTH*2] = {""};
    unsigned int bufferlen;
    char *ldefault;
    BOOL result;

	if (!PyArg_ParseTuple (args, "ssis", &key, &buffer, &bufferlen, &ldefault)) {
        PyError::PyShowError ("PyScript Error", "Error while decoding an argument for GetRCString", "");
		return Py_BuildValue("i", 0);
	}
    result = ::GetRCString (key, localbuffer, ldefault, MAX_LINE_LENGTH*2);
    if (result == false)
        return Py_BuildValue("i", 0);
    return Py_BuildValue("s", localbuffer);
}

PyObject *LSAPIConfig::LCOpen (PyObject *self, PyObject *args) {
    char path;
    FILE* fhandle;
    
	if (!PyArg_ParseTuple (args, "s", &path)) {
        PyError::PyShowError ("PyScript Error", "Error while decoding an argument for LCOpen", "");
		return Py_BuildValue("i", 0);
	}
    fhandle = ::LCOpen ((LPCSTR) path);

    return Py_BuildValue("i", fhandle);
}

PyObject *LSAPIConfig::LCClose (PyObject *self, PyObject *args) {
    FILE *fhandle;
    BOOL result;
    
	if (!PyArg_ParseTuple (args, "i", &fhandle)) {
        PyError::PyShowError ("PyScript Error", "Error while decoding an argument for LCClose", "");
		return Py_BuildValue("i", 0);
	}
    result = ::LCClose (fhandle);
    if (result == TRUE)
        return Py_BuildValue("i", 1);
    else
        return Py_BuildValue("i", 0);
}

PyObject *LSAPIConfig::LCReadNextConfig (PyObject *self, PyObject *args) {
    FILE *fhandle;
    LPTSTR buffer;
    char localbuffer[MAX_LINE_LENGTH*2] = {""};
    LPCTSTR prefix;
    DWORD buflen;
    BOOL result;

	if (!PyArg_ParseTuple (args, "issi", &fhandle, &prefix, &buffer, &buflen)) {
        PyError::PyShowError ("PyScript Error", "Error while decoding an argument for LCReadNextLine", "");
		return Py_BuildValue("i", 0);
	}
    result = ::LCReadNextConfig (fhandle, prefix, localbuffer, sizeof (localbuffer));
    if (result == FALSE)
        return Py_BuildValue("i", 0);
    return (Py_BuildValue ("s", localbuffer));
}

PyObject *LSAPIConfig::LCReadNextLine (PyObject *self, PyObject *args) {
    FILE *fhandle;
    LPTSTR buffer;
    char localbuffer[MAX_LINE_LENGTH*2] = {""};
    DWORD buflen;
    BOOL result;

	if (!PyArg_ParseTuple (args, "isi", &fhandle, &buffer, &buflen)) {
        PyError::PyShowError ("PyScript Error", "Error while decoding an argument for LCReadNextConfig", "");
		return Py_BuildValue("i", 0);
	}
    result = ::LCReadNextLine (fhandle, localbuffer, sizeof (localbuffer));
    if (result == FALSE)
        return Py_BuildValue("i", 0);
    return (Py_BuildValue ("s", localbuffer));
}

LSAPI BOOL LSGetVariable(LPCSTR pszKeyName, LPSTR pszValue);
LSAPI BOOL LSGetVariableEx(LPCSTR pszKeyName, LPSTR pszValue, DWORD dwLength);
LSAPI void LSSetVariable(LPCSTR pszKeyName, LPCSTR pszValue);

PyObject *LSAPIConfig::LSGetVariable (PyObject *self, PyObject *args) {
	char *key;
	char *value;
	char localbuffer[MAX_LINE_LENGTH*2] = {""};
	BOOL result;
	if (!PyArg_ParseTuple (args, "ss", &key, &value)) {
		PyError::PyShowError ("PyScript Error", "Error while decoding an argument for LSGetVariable", "");
		return Py_BuildValue("i", 0);
	}
	result = ::LSGetVariableEx (key, localbuffer, MAX_LINE_LENGTH*2);
	if (result == false) {
        return Py_BuildValue("i", 0);
	}
    return Py_BuildValue("s", localbuffer);
}

PyObject *LSAPIConfig::LSGetVariableEx (PyObject *self, PyObject *args) {
	char *key;
	char *value;
	char *dwLen;
	char localbuffer[MAX_LINE_LENGTH*2] = {""};
	BOOL result;
	if (!PyArg_ParseTuple (args, "ssi", &key, &value, &dwLen)) {
		PyError::PyShowError ("PyScript Error", "Error while decoding an argument for LSGetVariable", "");
		return Py_BuildValue("i", 0);
	}
	result = ::LSGetVariableEx (key, localbuffer, MAX_LINE_LENGTH*2);
    if (result == false)
        return Py_BuildValue("i", 0);
    return Py_BuildValue("s", localbuffer);
}

PyObject *LSAPIConfig::LSSetVariable (PyObject *self, PyObject *args) {
	char *key;
	char *value;

	if (!PyArg_ParseTuple (args, "ss", &key, &value)) {
		PyError::PyShowError ("PyScript Error", "Error while decoding an argument for LSSetVariable", "");
		return Py_BuildValue("i", 0);
	}
	::LSSetVariable (key, value);
    return Py_BuildValue("i", 1);
}

