#include <python.h>
#include "lsapi.h"
#include "PyError.h"
#include "LSAPIHelpers.h"


PyObject *LSAPIHelpers::GetLitestepWnd (PyObject *self, PyObject *args) {
    HWND hwnd = ::GetLitestepWnd ();
    return Py_BuildValue("i", hwnd);
}

PyObject *LSAPIHelpers::LCTokenize (PyObject *self, PyObject *args) {
    return Py_BuildValue("i", 0);
}

PyObject *LSAPIHelpers::LSExecute (PyObject *self, PyObject *args) {
    HWND hwnd;
    char *command;
    int showCmd;

	if (!PyArg_ParseTuple (args, "isi", &hwnd, &command, &showCmd)) {
        PyError::PyShowError ("PyScript Error", "Error while decoding an argument for LSExecute", "");
		return Py_BuildValue("i", 0);
	}
	else {    
		::LSExecute (hwnd, command, showCmd);  
		return Py_BuildValue("i", 1);
	}
    
}

PyObject *LSAPIHelpers::LSExecuteEx (PyObject *self, PyObject *args) {
    HWND hwndCaller;
    LPCSTR pszOperation, pszCommand, pszArguments, pszDirectory;
    int nShowCmd;

	if (!PyArg_ParseTuple (args, "issssi", &hwndCaller, &pszOperation, &pszCommand, &pszArguments, &pszDirectory, &nShowCmd)) {
        PyError::PyShowError ("PyScript Error", "Error while decoding an argument for LSExecuteEx", "");
		return Py_BuildValue("i", 0);
	}
	else {
		::LSExecuteEx (hwndCaller, pszOperation, pszCommand, pszArguments, pszDirectory, nShowCmd);
		return Py_BuildValue("i", 1);
	}
}

PyObject *LSAPIHelpers::LSGetImagePath (PyObject *self, PyObject *args) {
    char buffer[MAX_LINE_LENGTH+1];
    ::LSGetImagePath (buffer, sizeof (buffer));
    return Py_BuildValue("s", buffer);
}

PyObject *LSAPIHelpers::LSGetLitestepPath (PyObject *self, PyObject *args) {
    char buffer[MAX_LINE_LENGTH+1];
    ::LSGetLitestepPath (buffer, sizeof (buffer));
    return Py_BuildValue("s", buffer);
}

PyObject *LSAPIHelpers::VarExpansion (PyObject *self, PyObject *args) {
    PyObject *pyexpandedString;
    char expandedString[MAX_LINE_LENGTH*10] = {""};
    char *evar;

	if (!PyArg_ParseTuple (args, "ss", &expandedString, &evar)) {
        PyError::PyShowError ("PyScript Error", "Error while decoding an argument for VarExpansion", "");
		return Py_BuildValue("i", 0);
	}
	else {
		::VarExpansionEx (expandedString, evar, sizeof (expandedString));
	    pyexpandedString = Py_BuildValue ("s", expandedString);
		return pyexpandedString; 
	}
	
}

PyObject *LSAPIHelpers::VarExpansionEx (PyObject *self, PyObject *args) {
    PyObject *pyexpandedString;
    char *expandedString;
    char *evar;
    int maxsize;

	if (!PyArg_ParseTuple (args, "ssi", &expandedString, &evar, &maxsize)) {
        PyError::PyShowError ("PyScript Error", "Error while decoding an argument for VarExpansionEx", "");
		return Py_None;
	}

    expandedString = new char(maxsize+1);
    ::VarExpansionEx (expandedString, evar, maxsize);
    
    pyexpandedString = Py_BuildValue ("s", expandedString);
    delete expandedString;
    return pyexpandedString; 
}
