#include "PyError.h"
#include "PyExtension.h"

#include "LSAPIBangs.h"
#include "LSAPIConfig.h"
#include "LSAPIDebug.h"
#include "LSAPIGraphics.h"
#include "LSAPIHelpers.h"


PyExtension *PyExtension::extension = 0;

PyMethodDef PyExtension::LSAPIEmbedMethods[] = {
    {"AddBangCommand", LSAPIBangs::AddBangCommand, METH_VARARGS,
    "The AddBangCommand function registers a bang command."},
    {"AddBangCommandEx", LSAPIBangs::AddBangCommandEx, METH_VARARGS,
    "The AddBangCommandEx function registers a bang command."},
    {"ParseBangCommand", LSAPIBangs::ParseBangCommand, METH_VARARGS,
    "The ParseBangCommand function executes a bang command."},
    {"RemoveBangCommand", LSAPIBangs::RemoveBangCommand, METH_VARARGS,
    "The RemoveBangCommand function removes a previously registerd bang command."},
    {"GetRCBool", LSAPIConfig::GetRCBool, METH_VARARGS,
    "The GetRCBool function reads a boolean value from the step.rc file."},
    {"GetRCBoolDef", LSAPIConfig::GetRCBoolDef, METH_VARARGS,
    "The GetRCBoolDef function reads a boolean value from the step.rc."},
    {"GetRCColor", LSAPIConfig::GetRCColor, METH_VARARGS,
    "The GetRCColor reads a color value in either hexadecimal or R G B notation."},
    {"GetRCCoordinate", LSAPIConfig::GetRCCoordinate, METH_VARARGS,
    "The GetRCCoordinate reads a coordinate value in either and parses it into a integer."},
    {"GetRCInt", LSAPIConfig::GetRCInt, METH_VARARGS,
    "The GetRCInt function reads an integer value from the step.rc file."},
    {"GetRCLine", LSAPIConfig::GetRCLine, METH_VARARGS,
    "The GetRCLine reads a line from the step.rc."},
    {"GetRCString", LSAPIConfig::GetRCString, METH_VARARGS,
    "The GetRCString reads a string value from the step.rc."},
    {"LCOpen", LSAPIConfig::LCOpen, METH_VARARGS,
    "The LCOpen function opens a file for reading."},
    {"LCClose", LSAPIConfig::LCClose, METH_VARARGS,
    "The LCClose function closes a file."},
    {"LCReadNextConfig", LSAPIConfig::LCReadNextConfig, METH_VARARGS,
    "The LCReadNextConfig function searches for and reads a line from the step.rc."},
    {"LCReadNextLine", LSAPIConfig::LCReadNextLine, METH_VARARGS,
    "The LCReadNextLine functions reads a line from a file opened with LCOpen."},
	{"LSGetVariable", LSAPIConfig::LSGetVariable, METH_VARARGS,
    "LSGetVariable reads an evar."},
	{"LSGetVariableEx", LSAPIConfig::LSGetVariableEx, METH_VARARGS,
    "LSGetVariableEx reads an evar."},
	{"LSSetVariable", LSAPIConfig::LSSetVariable, METH_VARARGS,
    "LSSetVariable writes an evar."},
    {"LSLog", LSAPIDebug::LSLog, METH_VARARGS,
    "The LSLog function writes a string to the log."},
    {"LSLogPrintf", LSAPIDebug::LSLog, METH_VARARGS,
    "The LSLogPrintf function writes user-formatted string to the log."},
    {"BitmapFromIcon", LSAPIGraphics::BitmapFromIcon, METH_VARARGS,
    "The BitmapFromIcon function converts an icon into a bitmap. The transparent areas of the icon become magic pink in the bitmap."},
    {"BitmapToRegion", LSAPIGraphics::BitmapToRegion, METH_VARARGS,
    "The BitmapToRegion function creates a window region using the supplied bitmap."},
    {"GetLSBitmapSize", LSAPIGraphics::GetLSBitmapSize, METH_VARARGS,
    "The GetLSBitmapSize function gets the height and width of an HBITMAP."},
    {"LoadLSIcon", LSAPIGraphics::LoadLSIcon, METH_VARARGS,
    "The LoadLSIcon function loads an icon from an icon file."},
    {"LoadLSImage", LSAPIGraphics::LoadLSImage, METH_VARARGS,
    "The LoadLSImage function loads an image from a file. It currently supports Windows Bitmaps (BMP). Portable Network Graphics (PNG). Windows Icon files (ICO)."},
    {"TransparentBltLS", LSAPIGraphics::TransparentBltLS, METH_VARARGS,
    "The TransparentBltLS function overlays a source device context onto a destination device context, making all pixels of a certain color in the source device context transparent."},
    {"GetLitestepWnd", LSAPIHelpers::GetLitestepWnd, METH_VARARGS,
    "GetLitestepWnd returns a handle to the main Litestep window."},
    {"LCTokenize", LSAPIHelpers::LCTokenize, METH_VARARGS,
    "LCTokenize breaks up a string into tokens."},
    {"LSExecute", LSAPIHelpers::LSExecute, METH_VARARGS,
    "LSExecute executes a bang command or application."},
    {"LSExecuteEx", LSAPIHelpers::LSExecuteEx, METH_VARARGS,
    "LSExecuteEx executes a bang command or application."},
    {"LSGetImagePath", LSAPIHelpers::LSGetImagePath, METH_VARARGS,
    "The LSGetImagePath function gives you the path to the image directory."},
    {"LSGetLitestepPath", LSAPIHelpers::LSGetLitestepPath, METH_VARARGS,
    "LSGetLitestepPath retrieves the path to the Litestep directory."},
    {"VarExpansion", LSAPIHelpers::VarExpansion, METH_VARARGS,
    "VarExpansion replaces $vars$ in a string with their values."},
    {"VarExpansionEx", LSAPIHelpers::VarExpansionEx, METH_VARARGS,
    "VarExpansionEx replaces $vars$ in a string with their values."},
    {NULL, NULL, 0, NULL} 
};

PyExtension::PyExtension(void) {    
    Py_InitModule ("LSAPI", LSAPIEmbedMethods);
}
